Soil Group and ID_Rag Determination
Source:R/calc_soil_group_and_id_rag.R
calc_soil_group_and_id_rag.RdDetermines the soil group and ID_Rag based on clay and sand percentages using the USDA soil texture triangle.
Usage
calc_soil_group_and_id_rag(
clay = 10,
sand = 35,
tri3.table = NFert::tri3.table,
soil.table = NFert::soil.table
)Arguments
- clay
Percentage of clay in the soil (0-100).
- sand
Percentage of sand in the soil (0-100).
- tri3.table
A matrix containing the simplified soil texture classes based on clay and sand percentages. The default is
NFert::tri3.table.- soil.table
A data frame mapping soil texture classes (ID_Suo) to soil groups and ID_Rag. It should have at least three columns:
ID_Suo,Group, andID_Rag. The default is obtained from the NFert package.
Value
A named list containing:
soil.group: The soil group based on the USDA classification.
id_rag: The corresponding ID_Rag (numeric ID for the soil group).