Calculates the natural nitrogen (N) contribution from atmospheric deposition based on location and crop category.
Arguments
- location
The location or type of area (e.g., "Plain adjacent to urbanized areas"). Must match a value in the
locationcolumn of theg.table.- ccp
Crop category and planting period (e.g., "Autumn-winter crop <150 days"). Must match a value in the
ccpcolumn of thecoef_timetable.- g.table
A data frame containing annual nitrogen deposition rates for different locations. It should have at least two columns:
location(character) andannual_deposition(numeric). Defaults toNFert::g.table.- coef_time
A data frame containing adjustment factors (C_tempo) based on crop category and planting period. It should have at least two columns:
ccp(character) andC_tempo(numeric). Defaults toNFert::coef_time.
Value
The estimated natural nitrogen contribution in kg/ha, or NA if input values are not found in the respective tables.